# -*- coding: utf-8 -*-
__author__ = "Paul Schifferer <dm@sweetrpg.com>"
"""Constants.
"""


BUILD_INFO_PATH = "BUILD_INFO_PATH"
APPLICATION_BASE_PATH = "APPLICATION_BASE_PATH"
STATIC_ASSET_PREFIX = "STATIC_ASSET_PREFIX"

# global keys
SWEETRPG_API_CLIENT_KEY = "sweetrpg-api-client"

# cookies
SWEETRPG_AUTH_KEY = 'sweetrpg-auth'

# session keys
PROFILE_KEY = "profile"
JWT_PAYLOAD = "jwt_payload"
CURRENT_USER_ID = "current_user_id"
SESSION_ACCESS_TOKEN = "access_token"
SESSION_EMAIL = "email"
SESSION_USER_ID = "user_id"
